@@ -5,4 +5,4 @@ from django.utils.translation import gettext_lazy as _
 class SalesmanCheckoutApp(AppConfig):
     name = 'salesman.checkout'
     label = 'salesmancheckout'
-    verbose_name = _("Checkout")
+    verbose_name = _("Salesman Checkout")
